@@ -1,5 +1,4 @@
 import logging
-import stat
 import re
 import os
 import argparse
@@ -180,7 +179,7 @@ def update_authorized_keys():
 
     # Write authorized_keys
     fd = open(os.path.join(home_path, '.ssh', 'authorized_keys'), 'w')
-    os.fchmod(fd, stat.S_IRUSR | stat.S_IWUSR)
+    os.fchmod(fd, 0o600)
     fd.write(authorized_keys)
     fd.close()
 
